from setuptools import setup


def readme():
    with open('README.rst') as f:
        return f.read()


setup(name='sleuth_automation',
      version='2.0.1',
      description='Python wrapper for SLEUTH urban growth model.',
      long_description=readme(),
      classifiers=[
          'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
          'Programming Language :: Python :: 2.7',
          'Operating System :: Unix',
          'Topic :: Scientific/Engineering :: Information Analysis',
          'Topic :: Scientific/Engineering :: Atmospheric Science',
          'Intended Audience :: Science/Research',
          'Topic :: Scientific/Engineering'],
      url='http://github.com/sostenibilidad-unam/sleuth_automation',
      author='Fidel Serrano, Rodrigo Garcia',
      author_email='rgarcia@iecologia.unam.mx',
      license='GPLv3',
      packages=['sleuth_automation'],
      data_files=[('templates', ['sleuth_automation/templates/condor_submit.jinja',
                                 'sleuth_automation/templates/scenario.jinja'])],
      install_requires=['pandas', 'jinja2', 'sh'],
      scripts=['bin/sleuth_run.py',
               'bin/create_sleuth_condor_batch.py'],
      zip_safe=False)



#!/usr/bin/env python

import os
import argparse
from os.path import join, abspath
from sh import which
import sleuth_automation as sleuth
from jinja2 import Environment, PackageLoader

description = """
This script will create a condor submit file for a batch of SLEUTH runs.
"""

parser = argparse.ArgumentParser(description=description)

parser.add_argument('--sleuth_path', required=True,
                    help='path to SLEUTH directory')
parser.add_argument('--region_dir',
                    required=True,
                    help='path to region dir containing locations')
parser.add_argument('--mpi_cores', default=0,
                    help="""number of cores available for MPI,
                            if 0 (default) don't use mpi""")
parser.add_argument('--predict_end', type=int, required=True,
                    help='ending year of prediction interval')
parser.add_argument('--montecarlo_iterations', type=int, default=50,
                    help='monte carlo iterations')
args = parser.parse_args()


if args.mpi_cores > 0:
    sleuth.configure(sleuth_path=args.sleuth_path,
                     use_mpi=True, mpi_cores=args.mpi_cores)
else:
    sleuth.configure(sleuth_path=args.sleuth_path,
                     use_mpi=False)


r = sleuth.Region(region_dir=args.region_dir,
                  predict_end=args.predict_end,
                  monte_carlo_iterations=args.montecarlo_iterations)

print "wrote " + r.build()
